@@ -8,11 +8,11 @@ App::Tel - A script for logging into devices
 
 =head1 VERSION
 
-0.2015_01
+0.2015_02
 
 =cut
 
-our $VERSION = eval  { 0.2015_01 };
+our $VERSION = eval  { 0.2015_02 };
 
 
 =head1 SYNOPSIS
@@ -42,6 +42,29 @@ use Hash::Merge::Simple qw (merge);
 use Module::Load;
 use v5.10;
 
+my $sleeper;
+
+sub mysleep(;@) { sleep }
+sub check_hostrange($$) { 0; }
+
+BEGIN {
+    if (eval 'require Time::HiRes') {
+        import Time::HiRes qw(sleep);
+        $sleeper = \&Time::HiRes::sleep;
+    }
+
+    if (eval 'require App::Tel::HostRange') {
+        import App::Tel::HostRange qw (check_hostrange);
+    }
+
+}
+
+sub import {
+    my $class = shift;
+    no warnings 'redefine';
+    *mysleep = $sleeper if defined $sleeper;
+}
+
 
 # For reasons related to state I needed to make $winch_it global
 # because it needs to be written to inside signals.
@@ -58,7 +81,6 @@ Creates a new App::Tel object.
 =cut
 
 sub new {
-
     my $infile = IO::File->new;
     $infile->IO::File::fdopen( \*STDIN, 'r' );
 
@@ -306,7 +328,7 @@ sub rtr_find {
 
     foreach my $h (@{$config->{rtr}}) {
         my $h2 = $h->{regex};
-        if ($host =~ /$h2/i) {
+        if ($host =~ /$h2/i || check_hostrange($h2, $host)) {
             $profile=merge($profile, $h);
             last;
         }
@@ -385,6 +407,7 @@ sub _stty_rows {
 sub _input_password {
     my $prompt = shift;
     $prompt ||= '';
+    die 'STDIN not a tty' if (!POSIX::isatty(\*STDIN));
     my $old_mode=IO::Stty::stty(\*STDIN,'-g');
     print "Enter password for $prompt: ";
     IO::Stty::stty(\*STDIN,'-echo');
@@ -957,6 +980,28 @@ sub interconnect {
 	return;
 }
 
+=head2 run_commands
+
+    $self->run_commands(@commands);
+
+TODO: Document this
+
+Figure out why "reload\ry" doesn't work
+
+=cut
+
+sub run_commands {
+    my $self = shift;
+    my $opts = $self->{opts};
+
+    foreach my $arg (@_) {
+        chomp($arg);
+        $self->send("$arg\r");
+        $self->expect($self->{timeout},'-re', $self->profile->{prompt});
+        mysleep($opts->{s}) if ($opts->{s});
+    }
+}
+
 =head2 control_loop
 
     $self->control_loop();
@@ -968,10 +1013,6 @@ command line, or via autocmds in the profile.
 
 Calling this without any commands will just run interact()
 
-TODO: We should probably move the command running into two methods that
-process_commands and run_commands to make them easier to test and reuse for
-other things.
-
 =cut
 
 sub control_loop {
@@ -996,7 +1037,7 @@ sub control_loop {
     @args = split(/;/, $opts->{c}) if ($opts->{c});
 
     if ($opts->{x}) {
-        open(my $X, '<', $opts->{x});
+        open(my $X, '<', $opts->{x}) || die "Can't open file $opts->{x}\n";
         @args = <$X>;
         close $X;
     }
@@ -1005,21 +1046,16 @@ sub control_loop {
         $self->expect($self->{timeout},'-re',$prompt);
         if (ref($pagercmd) eq 'CODE') {
             $pagercmd->();
-            undef $pagercmd;
         } elsif ($pagercmd) {
-            $self->send("$pagercmd\r");
-            $self->expect($self->{timeout},'-re',$prompt);
-        }
-        foreach my $arg (@args) {
-            chomp($arg);
-            $self->send("$arg\r");
-            $self->expect($self->{timeout},'-re',$prompt);
+            $self->run_commands("$pagercmd\r");
         }
+        $self->run_commands(@args);
         $self->send($profile->{logoutcmd} ."\r");
     } else {
-        foreach my $arg (@$autocmds) {
-            $self->send("$arg\r");
+        die 'STDIN Not a tty' if (!POSIX::isatty($self->{stdin}));
+        if ($autocmds) {
             $self->expect($self->{timeout},'-re',$prompt);
+            $self->run_commands(@$autocmds);
         }
         $self->interact($self->{stdin}, '\cD');
         # q\b is to end anything that's at a More prompt or other dialog and
